==> openjdk-24_24~16ea.orig.tar.xz: openjdk-24-24~16ea/test/hotspot/jtreg/gc/stress/systemgc/TestSystemGCWithShenandoah.java <==
/*
 * Copyright (c) 2017, 2018, Red Hat, Inc. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

package gc.stress.systemgc;

/*
 * @test id=default
 * @key stress
 * @library /
 * @requires vm.gc.Shenandoah
 * @summary Stress the Shenandoah GC full GC by allocating objects of different lifetimes concurrently with System.gc().
 *
 * @run main/othervm/timeout=300 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC
 *      -XX:+ShenandoahVerify
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 *
 * @run main/othervm/timeout=300 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 */
public class TestSystemGCWithShenandoah {
    public static void main(String[] args) throws Exception {
        TestSystemGC.main(args);
    }
}

==> openjdk-26_26~17ea.orig.tar.xz: openjdk-26-26~17ea/test/hotspot/jtreg/gc/stress/systemgc/TestSystemGCWithShenandoah.java <==
/*
 * Copyright (c) 2017, 2018, Red Hat, Inc. All rights reserved.
 * Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

package gc.stress.systemgc;

/*
 * @test id=default
 * @key stress
 * @library /
 * @requires vm.gc.Shenandoah
 * @summary Stress the Shenandoah GC full GC by allocating objects of different lifetimes concurrently with System.gc().
 *
 * @run main/othervm/timeout=540 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC
 *      -XX:+ShenandoahVerify
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 *
 * @run main/othervm/timeout=540 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 */

/*
 * @test id=generational
 * @key stress
 * @library /
 * @requires vm.gc.Shenandoah
 * @summary Stress the Shenandoah GC full GC by allocating objects of different lifetimes concurrently with System.gc().
 *
 * @run main/othervm/timeout=540 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC -XX:ShenandoahGCMode=generational
 *      -XX:+ShenandoahVerify
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 *
 * @run main/othervm/timeout=540 -Xlog:gc*=info -Xmx512m -XX:+UnlockExperimentalVMOptions -XX:+UnlockDiagnosticVMOptions
 *      -XX:+UseShenandoahGC -XX:ShenandoahGCMode=generational
 *      gc.stress.systemgc.TestSystemGCWithShenandoah 270
 */
public class TestSystemGCWithShenandoah {
    public static void main(String[] args) throws Exception {
        TestSystemGC.main(args);
    }
}
